@@ -15,7 +15,7 @@ use Time::HiRes qw( sleep time );
 use Fcntl qw( :flock O_RDONLY );
 use base qw( Exporter );
 
-our $VERSION = '1.605';
+our $VERSION = '1.606';
 
 our ($display_die_with_localtime, $display_warn_with_localtime);
 our ($main_proc_id, $prog_name, $tmp_dir);
@@ -84,7 +84,7 @@ sub import {
 
    my ($_tmp_dir_base, $_count); $_count = 0;
 
-   if (exists $ENV{TEMP}) {
+   if (exists $ENV{TEMP} && -d $ENV{TEMP} && -w $ENV{TEMP}) {
       if ($_is_MSWin32) {
          $_tmp_dir_base = $ENV{TEMP} . '/mce';
          mkdir $_tmp_dir_base unless (-d $_tmp_dir_base);
@@ -505,7 +505,7 @@ MCE::Signal - Temporary directory creation/cleanup and signal handling
 
 =head1 VERSION
 
-This document describes MCE::Signal version 1.605
+This document describes MCE::Signal version 1.606
 
 =head1 SYNOPSIS
 
